package com.gic.haoban.manage.service.service.out.impl;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import cn.hutool.core.collection.CollectionUtil;

import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.Page;
import com.gic.clerk.api.dto.ClerkDTO;
import com.gic.clerk.api.service.ClerkService;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.api.dto.EnterpriseDTO;
import com.gic.enterprise.api.dto.StoreDTO;
import com.gic.enterprise.api.dto.StoreDetailDTO;
import com.gic.enterprise.api.service.EnterpriseService;
import com.gic.enterprise.api.service.StoreService;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.common.utils.PageUtil;
import com.gic.haoban.common.utils.UuidUtil;
import com.gic.haoban.communicate.api.service.SyncHaobanToGicServiceApi;
import com.gic.haoban.manage.api.dto.AuditDTO;
import com.gic.haoban.manage.api.dto.AuditStaffDTO;
import com.gic.haoban.manage.api.dto.BatchAuditLogDTO;
import com.gic.haoban.manage.api.dto.StaffClerkRelationDTO;
import com.gic.haoban.manage.api.dto.StaffDepartmentRelatedDTO;
import com.gic.haoban.manage.api.dto.StoreAddressDTO;
import com.gic.haoban.manage.api.enums.AppPageType;
import com.gic.haoban.manage.api.enums.AuditRsultType;
import com.gic.haoban.manage.api.enums.AuditType;
import com.gic.haoban.manage.api.enums.StoreFieldEnum;
import com.gic.haoban.manage.api.service.AuditApiService;
import com.gic.haoban.manage.api.service.StaffClerkRelationApiService;
import com.gic.haoban.manage.api.service.StaffDepartmentRelatedApiService;
import com.gic.haoban.manage.service.config.Config;
import com.gic.haoban.manage.service.dao.mapper.DepartmentMapper;
import com.gic.haoban.manage.service.dao.mapper.StaffMapper;
import com.gic.haoban.manage.service.dao.mapper.TabHaobanAuditMapper;
import com.gic.haoban.manage.service.dao.mapper.TabHaobanBatchAuditLogMapper;
import com.gic.haoban.manage.service.dao.mapper.WxEnterpriseMapper;
import com.gic.haoban.manage.service.entity.TabHaobanAudit;
import com.gic.haoban.manage.service.entity.TabHaobanBatchAuditLog;
import com.gic.haoban.manage.service.entity.TabHaobanDepartment;
import com.gic.haoban.manage.service.entity.TabHaobanStaff;
import com.gic.haoban.manage.service.entity.TabHaobanWxEnterprise;
import com.gic.wechat.api.dto.qywx.ItemDTO;
import com.gic.wechat.api.dto.qywx.QywxXcxSendMessageDTO;
import com.gic.wechat.api.service.qywx.QywxSuiteApiService;
import com.github.pagehelper.PageHelper;

/**
 * Created by tgs on 2020/2/9.
 */
@Service
public class AuditApiServiceImpl implements AuditApiService{
	private static Logger logger  = LoggerFactory.getLogger(AuditApiServiceImpl.class);

	@Autowired
	private TabHaobanAuditMapper auditMapper;
	@Autowired
	private DepartmentMapper departmentMapper;
	@Autowired
	private StaffMapper staffMapper;
	@Autowired
	private StoreService storeService;
	@Autowired
	private QywxSuiteApiService qywxSuiteApiService;
	@Autowired
	private Config config;
	@Autowired
	private WxEnterpriseMapper wxEnterpriseMapper;
	@Autowired
	private TabHaobanBatchAuditLogMapper tabHaobanBatchAuditLogMapper;
	@Autowired
	private StaffDepartmentRelatedApiService staffDepartmentRelatedApiService;
	@Autowired
	private EnterpriseService enterpriseService;
	@Autowired
	private SyncHaobanToGicServiceApi syncHaobanToGicServiceApi;
	@Autowired
	private StaffClerkRelationApiService staffClerkRelationApiService;
	@Autowired
	private ClerkService clerkService;
	
	@Override
	public Page<AuditDTO> page(Integer auditType, String search,String wxEnterpriseId,
			String enterpriseId,Integer auditStatus,Integer auditFlag, BasePageInfo pageInfo) {
		//部门关联表修改，服务层调整
		List<String> departmentIds = new ArrayList<>();
		List<String> staffIds = new ArrayList<>();
		List<String> storeIds = new ArrayList<>();
		if(StringUtils.isNotEmpty(search)){
			
			List<StoreDTO> list = storeService.searchStoreByCodeOrName(enterpriseId,search);
			if(CollectionUtil.isNotEmpty(list)){
				List<String> storeIds1 = list.stream().map(s->s.getStoreId()).collect(Collectors.toList());
				storeIds.addAll(storeIds1);
			}
			
			List<TabHaobanStaff> staffList = staffMapper.listLikeName(search);
			if(CollectionUtil.isNotEmpty(staffList)){
				List<String> staffIds2 = staffList.stream().map(s->s.getStaffId()).collect(Collectors.toList());
				staffIds.addAll(staffIds2);
			}
			if(CollectionUtil.isEmpty(staffIds)){
				staffIds.add("-999");
			}
			if(CollectionUtil.isEmpty(storeIds)){
				storeIds.add("-999");
			}
		}
		PageHelper.startPage(pageInfo.getPageNum(), pageInfo.getPageSize());
		com.github.pagehelper.Page<TabHaobanAudit> page = new com.github.pagehelper.Page<TabHaobanAudit>();
		if(CollectionUtil.isNotEmpty(storeIds)&&CollectionUtil.isNotEmpty(staffIds)){
			page = auditMapper.pageForStoreIdsAndstaffIds(auditType, storeIds, staffIds, wxEnterpriseId,enterpriseId,auditStatus,auditFlag);
		}else{
			page = auditMapper.page(auditType, storeIds, staffIds, wxEnterpriseId,enterpriseId,auditStatus,auditFlag);
		}
		if(CollectionUtil.isNotEmpty( page.getResult())){
			List<String> commitStaffIds =  page.getResult().stream().map(s->s.getCommitStaffId()).collect(Collectors.toList());
			List<TabHaobanStaff> staffList = staffMapper.listByIds(commitStaffIds);
			Map<String,TabHaobanStaff> map = com.gic.commons.util.CollectionUtil.toMap(staffList, "staffId");
			for(TabHaobanAudit tab: page.getResult()){
				String commitStaffId = tab.getCommitStaffId();
				tab.setCommitStaffName(map.get(commitStaffId)==null?"":map.get(commitStaffId).getStaffName());
				tab.setCommitStaffImg(map.get(commitStaffId)==null?"":map.get(commitStaffId).getHeadImg());
			}
		}
		return PageUtil.changePageHelperToCurrentPage( page,AuditDTO.class);
	}
	@Transactional
	@Override
	public String audit(String batchId,String auditId,String auditName) {
		TabHaobanAudit tab = auditMapper.selectByPrimaryKey(auditId);
		if(tab==null){
			return "审核项目不存在";
		}
		int auditType = tab.getAuditType();
		tab.setAuditId(auditId);
		tab.setUpdateTime(new Date());
		tab.setAuditName(auditName);
		if(auditType == AuditType.STORE_CHANGE.getCode()){
			//门店信息变更
			String storeId = tab.getCommitStoreId();
			String oldValue = tab.getOldValue();
			String newValue = tab.getNewValue();
			String changeField = tab.getChangeField();
			this.editStoreInfo(storeId, changeField, oldValue, newValue);
			//发送消息
			String title = "门店信息修改通知";
			String content = StoreFieldEnum.getValueName(changeField);
			content = "["+content+"]"+"修改审核通过";
			TabHaobanAudit tab2 = auditMapper.selectByPrimaryKey(auditId);
			String staffId = tab2.getCommitStaffId();
			this.sendMessageByStaffId(staffId, storeId, title, content);
			//插入log
			if(org.apache.commons.lang.StringUtils.isNotBlank(batchId)){
				 insertBatchLog( batchId,AuditRsultType.success.getCode(), tab);
			}
		}else if(auditType == AuditType.CLERK_BIND.getCode()){
			//门店导购绑定
			String oldValue = tab.getOldValue();
			AuditStaffDTO obj = JSONObject.parseObject(oldValue,AuditStaffDTO.class);
			StaffClerkRelationDTO staffClerkRelation  = staffClerkRelationApiService.getByCodeAndEnterpriseId(obj.getClerkCode(),tab.getEnterpriseId());
			String staffId = obj.getStaffId();
			String storeId = tab.getCommitStoreId();
			StaffClerkRelationDTO have = staffClerkRelationApiService.getOneByStoreIdAndStaffId(storeId, staffId);
			if(have !=null){
				tab.setAuditStatus(5);
				tab.setAuditReason("该成员在该门店下已经绑定过一个导购了");
				auditMapper.updateByPrimaryKeySelective(tab);	
				if(org.apache.commons.lang.StringUtils.isNotBlank(batchId)){
					 insertBatchLog( batchId,AuditRsultType.fail.getCode(),tab);
				}
				return "该成员在该门店下已经绑定过一个导购了";
			}
			
			ClerkDTO clerkDTO = clerkService.getClerkByClerkId(obj.getClerkId());
			if(clerkDTO == null){
				tab.setAuditStatus(5);
				tab.setAuditReason("gic已删除该导购");
				auditMapper.updateByPrimaryKeySelective(tab);	
				if(org.apache.commons.lang.StringUtils.isNotBlank(batchId)){
					 insertBatchLog( batchId,AuditRsultType.fail.getCode(),tab);
				}
				return "gic已删除该导购";
			}else{
				if(staffClerkRelation == null){
					staffClerkRelation = new StaffClerkRelationDTO();
				}
				staffClerkRelation.setEnterpriseId(tab.getEnterpriseId());
				staffClerkRelation.setClerkCode(obj.getClerkCode());
				staffClerkRelation.setClerkId(obj.getClerkId());
				staffClerkRelation.setStoreId(tab.getCommitStoreId());
				staffClerkRelation.setWxEnterpriseId(tab.getWxEnterpriseId());
				staffClerkRelation.setWxUserId(obj.getWxUserId());
				staffClerkRelation.setStaffId(obj.getStaffId());
				staffClerkRelationApiService.delAndInsert(staffClerkRelation);			}
			if(org.apache.commons.lang.StringUtils.isNotBlank(batchId)){
				 insertBatchLog( batchId,AuditRsultType.success.getCode(), tab);
			}
			staffDepartmentRelatedApiService.sendClerkBind(obj.getStaffId(), obj.getClerkCode(),storeId, 1, "");
    		
		}else if(auditType == AuditType.CLERK_ADD.getCode()){
			//门店导购新增
			String oldValue = tab.getOldValue();
			AuditStaffDTO obj = JSONObject.parseObject(oldValue,AuditStaffDTO.class);
			boolean flag = syncHaobanToGicServiceApi.syncClerkToGicClerkAdd(tab.getCommitStoreId(), obj.getClerkCode(), obj.getSex(), obj.getClerkName(), obj.getPhoneNumber(), obj.getNationCode(), null);
			if(!flag){
				//失败
				tab.setAuditStatus(5);
				tab.setAuditReason("gic新增导购失败");
				auditMapper.updateByPrimaryKeySelective(tab);	
				if(org.apache.commons.lang.StringUtils.isNotBlank(batchId)){
					 insertBatchLog( batchId,AuditRsultType.fail.getCode(), tab);
				}		
				return "gic新增导购失败";
			}else{
				//成功
				if(org.apache.commons.lang.StringUtils.isNotBlank(batchId)){
					 insertBatchLog( batchId,1, tab);
				}
				staffDepartmentRelatedApiService.sendClerkAdd(tab.getEnterpriseId(), obj.getClerkCode(), 1, "");
			}

		}else if(auditType == AuditType.CLERK_DEL.getCode()){
			//门店导购删除
			String oldValue = tab.getOldValue();
			AuditStaffDTO obj = JSONObject.parseObject(oldValue,AuditStaffDTO.class);
			syncHaobanToGicServiceApi.delGicClerk(obj.getClerkId());
			if(org.apache.commons.lang.StringUtils.isNotBlank(batchId)){
				 insertBatchLog( batchId,AuditRsultType.success.getCode(),tab);
			}
			staffClerkRelationApiService.delByClerkId(obj.getClerkId());
			
			staffDepartmentRelatedApiService.sendClerkDel(obj.getClerkName(), obj.getClerkCode(),tab.getCommitStoreId(), 1, "");
		}else if(auditType == AuditType.CLERK_UNBIND.getCode()){
			//解绑申请，无需审核，直接通过
		}
		tab.setAuditStatus(1);
		auditMapper.updateByPrimaryKeySelective(tab);	
		return "";
	}
	@Override
	public void refuse(String auditId, String auditReason,String auditName) {
		TabHaobanAudit tab = new TabHaobanAudit();
		tab.setAuditId(auditId);
		tab.setAuditStatus(2);
		tab.setUpdateTime(new Date());
		tab.setAuditReason(auditReason);
		tab.setAuditName(auditName);
		auditMapper.updateByPrimaryKeySelective(tab);	
		TabHaobanAudit tab2 = auditMapper.selectByPrimaryKey(auditId);
		int auditType = tab2.getAuditType();
		String oldValue = tab2.getOldValue();
		String enterpriseId = tab2.getEnterpriseId();
		//发送消息
		if(auditType == AuditType.STORE_CHANGE.getCode()){
			String changeField = tab2.getChangeField();
			String title = "门店信息修改通知";
			String content = StoreFieldEnum.getValueName(changeField);
			content = "["+content+"]"+"被拒绝。拒绝理由："+auditReason;
			String staffId = tab2.getCommitStaffId();
			String storeId = tab2.getCommitStoreId();
			this.sendMessageByStaffId(staffId, storeId, title, content);
		}else if(auditType == AuditType.CLERK_BIND.getCode()){
			AuditStaffDTO obj = JSONObject.parseObject(oldValue,AuditStaffDTO.class);
			staffDepartmentRelatedApiService.sendStaffBind(obj.getStaffId(), obj.getClerkCode(), tab2.getCommitStoreId(), 2, auditReason);
		}else if(auditType == AuditType.CLERK_ADD.getCode()) {
			AuditStaffDTO obj = JSONObject.parseObject(oldValue,AuditStaffDTO.class);
			staffDepartmentRelatedApiService.sendClerkAdd(enterpriseId, obj.getClerkCode(), 2, auditReason);
		}else if(auditType == AuditType.CLERK_DEL.getCode()) {
			AuditStaffDTO obj = JSONObject.parseObject(oldValue,AuditStaffDTO.class);
			staffDepartmentRelatedApiService.sendClerkDel(obj.getClerkName(), obj.getClerkCode(),tab2.getCommitStoreId(), 2, auditReason);
		}
	}
	@Override
	public int  save(Integer auditType,String wxEnterpriseId, String enterpriseId,
			String commitStaffId, String commitStoreId, String changeField,
			String oldValue, String newValue) {
		TabHaobanStaff staff = staffMapper.selectByPrimaryKey(commitStaffId);
		if(staff == null){
			return 0;
		}
		TabHaobanAudit tab = new TabHaobanAudit();	
		tab.setAuditId(UuidUtil.randomUUID());
		tab.setAuditStatus(0);
		tab.setAuditType(auditType);
		tab.setChangeField(changeField);
		tab.setCommitName(null);
		tab.setCommitStaffId(commitStaffId);
		tab.setCommitStaffImg(staff.getHeadImg());
		tab.setCommitStaffName(staff.getStaffName());
		tab.setCommitStoreId(commitStoreId);
		tab.setCommitTime(new Date());
		tab.setCreateTime(new Date());
		tab.setWxEnterpriseId(wxEnterpriseId);
		tab.setEnterpriseId(enterpriseId);
		tab.setNewValue(newValue);
		tab.setOldValue(oldValue);
		tab.setStatusFlag(1);
		tab.setUpdateTime(new Date());
		return auditMapper.insertSelective(tab);
	}
	@Override
	public void editStoreInfo(String storeId, String changeField,
			String oldValue, String newValue) {
		logger.info("===================进11");
		StoreDTO store = storeService.getStore(storeId);
		if(!StoreFieldEnum.STORE_IMAG.getValue().equals(changeField)){
			 //非门店图片修改
			logger.info("===================进222");
			StoreDetailDTO detailDTO = new StoreDetailDTO();
			detailDTO =  EntityUtil.changeEntityByJSON(StoreDetailDTO.class, store);
			detailDTO.setStoreId(storeId);
			detailDTO.setEnterpriseId(store.getEnterpriseId());
			detailDTO.setStatus(2);
			detailDTO.setOpenTime(null);
			detailDTO.setCloseTime(null);
			getStoreDTO( detailDTO, changeField, oldValue, newValue);
			
			logger.info("detailDTO====================>为{}",JSONObject.toJSONString(detailDTO));
			storeService.saveStore(detailDTO);
//			storeService.saveOrUpdateStore(store);
		 }else{
			 //门店图片修改
				logger.info("===================进333");
			 storeService.updateStorePhotos(storeId, newValue);
		 }		
	}
	void getStoreDTO(StoreDetailDTO store,String changeField,String oldValue,String newValue){
		logger.info("==========================>changeField={}",changeField);
		if(StoreFieldEnum.BUSINESS_TIME_STRING.getValue().equals(changeField)){
			SimpleDateFormat sdf = new SimpleDateFormat("HH:mm");
			//营业时间
			String [] newValues = newValue.split("-");
			String openTime = newValues[0];
			String closeTime = newValues[1];
			store.setOpenTime(openTime);
			store.setCloseTime(closeTime);
		}else if(StoreFieldEnum.CONACTS_PHONE.getValue().equals(changeField)){
			//联系电话
			store.setConactsPhone(newValue);
		}else if(StoreFieldEnum.STORE_ADDRESS.getValue().equals(changeField)){
			logger.info("==========================>进来333");
			//门店地址
			StoreAddressDTO obj = JSONObject.parseObject(newValue,StoreAddressDTO.class);
			String areaId = obj.getAreaId();
			String storeAddress = obj.getStoreAddress();
			logger.info("==========================>areaId={},storeAddress={},newValue={}",areaId,storeAddress,newValue);
			String arr[] = storeAddress.split(" ");
			store.setAreaId(areaId);
			store.setFullArea(arr[0]);
			//避免多个空格造成数据混乱
			store.setStoreAddress(storeAddress.substring(storeAddress.indexOf(arr[0])+arr[0].length()+1));
		}else if(StoreFieldEnum.STORE_AREA.getValue().equals(changeField)){
			//门店面积
			store.setStoreArea(Double.parseDouble(newValue));
		}else if(StoreFieldEnum.STORE_NAME.getValue().equals(changeField)){
			//门店名字
			store.setStoreName(newValue);
//			TabHaobanDepartment tab = departmentMapper.getByRelatedId(store.getStoreId());
//			tab.setDepartmentName(newValue);
//			departmentMapper.updateByPrimaryKey(tab);
		}else if(StoreFieldEnum.STORE_IMAG.getValue().equals(changeField)){
			//门店图片
		}
	}
	@Override
	public List<AuditDTO> listByStoreId(String storeId) {
		List<TabHaobanAudit> list = auditMapper.listByStoreId(storeId);
		List<AuditDTO> resultList = EntityUtil.changeEntityListByJSON(AuditDTO.class, list);
		return resultList;
	}
	@Override
	public AuditDTO findByStoreIdAndChangeField(String storeId,
			String changeField) {
		TabHaobanAudit tab = auditMapper.findByStoreIdAndChangeField(storeId,changeField);
		if(tab == null){
			return null;
		}
		return EntityUtil.changeEntityByJSON(AuditDTO.class, tab);
	}
	
	
	public void sendMessageByStaffId(String staffId,String storeId,String title,String content){
		TabHaobanStaff staff = staffMapper.selectByPrimaryKey(staffId);
		if(staff == null){
			logger.info("staff不存在");
			return;
		}
		if(content.length()>30){
			content.substring(0, 26);
			content = content+"...";
		}
		String wxUserId = staff.getWxUserId();
		String staffName = staff.getStaffName();
		String wxEnterpriseId = staff.getWxEnterpriseId();
		TabHaobanWxEnterprise tabHaobanWxEnterprise = wxEnterpriseMapper.selectByPrimaryKey(wxEnterpriseId);
		String corpId = tabHaobanWxEnterprise.getCorpid();
		
		JSONObject jsonObject = new JSONObject();
		jsonObject.put("storeId", storeId);
		String data = jsonObject.toJSONString();
		String pageUrl = staffDepartmentRelatedApiService.getPageUrl(AppPageType.STORE_DETAIL.getCode(), data);
		
		QywxXcxSendMessageDTO messageDTO = new QywxXcxSendMessageDTO();
		List<ItemDTO> items = new ArrayList();;
		ItemDTO dto1 = new ItemDTO();
		ItemDTO dto2 = new ItemDTO();
		dto1.setKey("接收人");
		dto1.setValue(staffName);
		dto2.setKey("接收事件");
		dto2.setValue(content);
		items.add(dto1);
		items.add(dto2);
        ArrayList<String> list = new ArrayList<>();
        list.add(wxUserId);
		messageDTO.setAppid(config.getAppid());
        messageDTO.setUserIds(list);
        messageDTO.setPage(pageUrl);
        messageDTO.setTitle(title);
        messageDTO.setItems(items);
		boolean b = qywxSuiteApiService.sendMessage(corpId, config.getWxSuiteid(), messageDTO);

	}
	@Override
	public void insert(AuditDTO audit) {
		audit.setAuditId(com.gic.haoban.common.utils.StringUtil.randomUUID());
		audit.setCreateTime(new Date());
		audit.setUpdateTime(new Date());
		auditMapper.insertSelective(EntityUtil.changeEntityByJSON(TabHaobanAudit.class, audit));
	}
	@Override
	public Page<AuditDTO> listByStaffId(String staffId, Integer auditType,Integer auditStatus,BasePageInfo pageInfo) {
		PageHelper.startPage(pageInfo.getPageNum(), pageInfo.getPageSize());
		return PageUtil.changePageHelperToCurrentPage(auditMapper.listByStaffId(staffId,auditType,auditStatus),AuditDTO.class);
	}
	@Override
	public Page<AuditDTO> pageStoreListByParams(String storeId, BasePageInfo pageInfo, Integer auditType,
			Integer auditStatus) {
		PageHelper.startPage(pageInfo.getPageNum(), pageInfo.getPageSize());
		return PageUtil.changePageHelperToCurrentPage(auditMapper.pageStoreListByParams(storeId,auditType,auditStatus),AuditDTO.class);
	}
	
	public void insertBatchLog(String batchId,int auditResult,TabHaobanAudit tab){
		EnterpriseDTO enterprise = enterpriseService.getEnterpriseById(tab.getEnterpriseId());
		TabHaobanBatchAuditLog batTab = new TabHaobanBatchAuditLog();
		batTab.setAuditId(tab.getAuditId());
		batTab.setBatchAuditLogId(UuidUtil.randomUUID());
		batTab.setAuditType(tab.getAuditType());
		batTab.setAuditResult(auditResult);
		batTab.setBatchId(batchId);
		batTab.setCommitName(tab.getCommitStaffName());
		batTab.setCommitTime(tab.getCommitTime());
		batTab.setCreateTime(new Date());
		batTab.setEnterpriseName(enterprise == null ?"":enterprise.getEnterpriseName());
		batTab.setStatus(1);
		batTab.setUpdateTime(new Date());
		tabHaobanBatchAuditLogMapper.insert(batTab);
	}
	
	@Override
	public AuditDTO findById(String auditId) {
		return EntityUtil.changeEntityByJSON(AuditDTO.class, auditMapper.selectByPrimaryKey(auditId));
	}
	@Override
	public void update(AuditDTO audit) {
		audit.setUpdateTime(new Date());
		auditMapper.updateByPrimaryKeySelective(EntityUtil.changeEntityByJSON(TabHaobanAudit.class, audit));
	}
	@Override
	public List<BatchAuditLogDTO> listBatchLog(String batchId) {
		List<TabHaobanBatchAuditLog > list = tabHaobanBatchAuditLogMapper.listByBatchId(batchId);
		return EntityUtil.changeEntityListByJSON(BatchAuditLogDTO.class, list);
	}
	@Override
	public AuditDTO findByBindRelatedIdAndAuditType(String relatedId,
			int auditType) {
		TabHaobanAudit tab = auditMapper.findByBindRelatedIdAndAuditType(relatedId, auditType);
		return EntityUtil.changeEntityByJSON(AuditDTO.class, tab);
	}
	@Override
	public boolean judgeHavePhoneNumberOrCode(String enterpriseId,
			String clerkCode, String phoneNumber) {
		List<TabHaobanAudit>  list = auditMapper.judgeHavePhoneNumberOrCode(enterpriseId,clerkCode,phoneNumber);
		if(CollectionUtil.isEmpty(list)){
			return false;
		}else{
			return true;
		}
	}
	
}
